@@ -199,8 +199,8 @@ namespace SourceGit.Models
 
                 // Margins & merge state (used by Views.Histories).
                 commit.IsMerged = isMerged;
-                commit.Margin = new Thickness(Math.Max(offsetX, maxOffsetOld) + halfWidth + 2, 0, 0, 0);
                 commit.Color = dotColor;
+                commit.LeftMargin = Math.Max(offsetX, maxOffsetOld) + halfWidth + 2;
             }
 
             // Deal with curves haven't ended yet.
