@@ -58,7 +58,7 @@ namespace SourceGit.ViewModels
 
             if (!DiscardLocalChanges)
             {
-                var changes = await new Commands.CountLocalChangesWithoutUntracked(_repo.FullPath).GetResultAsync();
+                var changes = await new Commands.CountLocalChanges(_repo.FullPath, false).GetResultAsync();
                 if (changes > 0)
                 {
                     succ = await new Commands.Stash(_repo.FullPath)
@@ -98,7 +98,7 @@ namespace SourceGit.ViewModels
             log.Complete();
 
             var b = _repo.Branches.Find(x => x.IsLocal && x.Name == Branch);
-            if (b != null && _repo.HistoriesFilterMode == Models.FilterMode.Included)
+            if (b != null && _repo.HistoryFilterMode == Models.FilterMode.Included)
                 _repo.SetBranchFilterMode(b, Models.FilterMode.Included, false, false);
 
             _repo.MarkBranchesDirtyManually();
