@@ -65,7 +65,7 @@ namespace SourceGit.ViewModels
 
         public override async Task<bool> Sure()
         {
-            _repo.SetWatcherEnabled(false);
+            using var lockWatcher = _repo.LockWatcher();
             _repo.ClearCommitMessage();
             ProgressDescription = "Cherry-Pick commit(s) ...";
 
@@ -96,7 +96,6 @@ namespace SourceGit.ViewModels
             }
 
             log.Complete();
-            _repo.SetWatcherEnabled(true);
             return true;
         }
 
