@@ -142,7 +142,7 @@ namespace SourceGit.ViewModels
                 var needPopStash = false;
                 if (!DiscardLocalChanges)
                 {
-                    var changes = await new Commands.CountLocalChangesWithoutUntracked(_repo.FullPath).GetResultAsync();
+                    var changes = await new Commands.CountLocalChanges(_repo.FullPath, false).GetResultAsync();
                     if (changes > 0)
                     {
                         succ = await new Commands.Stash(_repo.FullPath)
@@ -216,7 +216,7 @@ namespace SourceGit.ViewModels
                 if (folderEndIdx > 10)
                     _repo.Settings.ExpandedBranchNodesInSideBar.Add(fake.FullName.Substring(0, folderEndIdx));
 
-                if (_repo.HistoriesFilterMode == Models.FilterMode.Included)
+                if (_repo.HistoryFilterMode == Models.FilterMode.Included)
                     _repo.SetBranchFilterMode(fake, Models.FilterMode.Included, false, false);
             }
 
