@@ -42,7 +42,7 @@ namespace SourceGit.ViewModels
 
         public override async Task<bool> Sure()
         {
-            _repo.SetWatcherEnabled(false);
+            using var lockWatcher = _repo.LockWatcher();
             ProgressDescription = $"Git Flow - Finish {Branch.Name} ...";
 
             var log = _repo.CreateLog("GitFlow - Finish");
@@ -53,7 +53,6 @@ namespace SourceGit.ViewModels
             var succ = await Commands.GitFlow.FinishAsync(_repo.FullPath, Type, name, Squash, AutoPush, KeepBranch, log);
 
             log.Complete();
-            _repo.SetWatcherEnabled(true);
             return succ;
         }
 
