@@ -1,5 +1,6 @@
 using System;
 using System.Collections.Generic;
+using System.Text;
 
 using Avalonia;
 using Avalonia.Controls;
@@ -73,18 +74,10 @@ namespace SourceGit.Views
                 MoveSelection(NavigationDirection.Next);
                 e.Handled = true;
             }
-            else if (e.KeyModifiers.HasFlag(OperatingSystem.IsMacOS() ? KeyModifiers.Meta : KeyModifiers.Control) && items.Count == 1)
+            else if (e.KeyModifiers.HasFlag(KeyModifiers.Control))
             {
-                if (e.Key == Key.Up)
-                {
-                    vm.MoveItemUp(items[0]);
-                    e.Handled = true;
-                }
-                else if (e.Key == Key.Down)
-                {
-                    vm.MoveItemDown(items[0]);
-                    e.Handled = true;
-                }
+                if (e.Key == Key.Up || e.Key == Key.Down)
+                    return;
             }
 
             if (!e.Handled)
@@ -92,6 +85,87 @@ namespace SourceGit.Views
         }
     }
 
+    public class InteractiveRebaseIndicator : Control
+    {
+        public static readonly StyledProperty<IBrush> FillProperty =
+            AvaloniaProperty.Register<InteractiveRebaseIndicator, IBrush>(nameof(Fill), Brushes.Transparent);
+
+        public IBrush Fill
+        {
+            get => GetValue(FillProperty);
+            set => SetValue(FillProperty, value);
+        }
+
+        public static readonly StyledProperty<Models.InteractiveRebasePendingType> PendingTypeProperty =
+            AvaloniaProperty.Register<InteractiveRebaseIndicator, Models.InteractiveRebasePendingType>(nameof(PendingType));
+
+        public Models.InteractiveRebasePendingType PendingType
+        {
+            get => GetValue(PendingTypeProperty);
+            set => SetValue(PendingTypeProperty, value);
+        }
+
+        public override void Render(DrawingContext context)
+        {
+            base.Render(context);
+
+            if (PendingType == Models.InteractiveRebasePendingType.None)
+                return;
+
+            var startW = 4;
+            var endW = Bounds.Width - 6;
+            var height = Bounds.Height;
+            var halfH = height * 0.5;
+            var fill = Fill;
+
+            if (PendingType == Models.InteractiveRebasePendingType.Last)
+            {
+                var center = new Point(startW, halfH);
+                context.DrawEllipse(fill, null, center, 4, 4);
+                context.DrawLine(new Pen(fill, 2), center, new Point(startW, height));
+            }
+            else if (PendingType == Models.InteractiveRebasePendingType.Ignore)
+            {
+                context.DrawLine(new Pen(fill, 2), new Point(startW, 0), new Point(startW, height));
+            }
+            else if (PendingType == Models.InteractiveRebasePendingType.Pending)
+            {
+                context.DrawEllipse(fill, null, new Point(startW, halfH), 4, 4);
+                context.DrawLine(new Pen(fill, 2), new Point(startW, 0), new Point(startW, height));
+            }
+            else
+            {
+                var geoPath = new StreamGeometry();
+                using (var ctx = geoPath.Open())
+                {
+                    ctx.BeginFigure(new Point(startW, 0), false);
+                    ctx.QuadraticBezierTo(new Point(startW, halfH), new Point(endW, halfH));
+                    ctx.EndFigure(false);
+                }
+                context.DrawGeometry(null, new Pen(fill, 2), geoPath);
+
+                var geoArrow = new StreamGeometry();
+                using (var ctx = geoPath.Open())
+                {
+                    ctx.BeginFigure(new Point(endW, halfH), true);
+                    ctx.LineTo(new Point(endW - 4, halfH + 2));
+                    ctx.LineTo(new Point(endW - 4, halfH - 2));
+                    ctx.EndFigure(true);
+                }
+                context.DrawGeometry(fill, null, geoArrow);
+            }
+        }
+
+        protected override void OnPropertyChanged(AvaloniaPropertyChangedEventArgs change)
+        {
+            base.OnPropertyChanged(change);
+
+            if (change.Property == FillProperty ||
+                change.Property == PendingTypeProperty)
+                InvalidateVisual();
+        }
+    }
+
     public partial class InteractiveRebase : ChromelessWindow
     {
         public InteractiveRebase()
@@ -103,8 +177,18 @@ namespace SourceGit.Views
 
         public void OpenCommitMessageEditor(ViewModels.InteractiveRebaseItem item)
         {
+            if (DataContext is not ViewModels.InteractiveRebase vm)
+                return;
+
             var dialog = new CommitMessageEditor();
-            dialog.AsBuiltin(item.FullMessage, msg => item.FullMessage = msg);
+            dialog.AsBuiltin(vm.ConventionalTypesOverride, item.FullMessage, msg =>
+            {
+                if (msg.Equals(item.FullMessage, StringComparison.Ordinal))
+                    return;
+
+                item.FullMessage = msg;
+                item.IsMessageUserEdited = true;
+            });
             dialog.ShowDialog(this);
         }
 
@@ -136,57 +220,172 @@ namespace SourceGit.Views
                 OpenCommitMessageEditor(items[0]);
         }
 
-        private void OnSetupRowHeaderDragDrop(object sender, RoutedEventArgs e)
+        private async void OnRowPointerPressed(object sender, PointerPressedEventArgs e)
         {
-            if (sender is Border border)
+            if (sender is not Control { DataContext: ViewModels.InteractiveRebaseItem item })
+                return;
+
+            var cmdKeyModifier = OperatingSystem.IsMacOS() ? KeyModifiers.Meta : KeyModifiers.Control;
+            if (e.KeyModifiers.HasFlag(KeyModifiers.Shift) || e.KeyModifiers.HasFlag(cmdKeyModifier))
+                return;
+
+            var builder = new StringBuilder();
+            var selected = IRItemListBox.SelectedItems ?? new List<object>();
+            if (selected.Count > 0 && !selected.Contains(item))
             {
-                DragDrop.SetAllowDrop(border, true);
-                border.AddHandler(DragDrop.DragOverEvent, OnRowHeaderDragOver);
+                IRItemListBox.SelectedItem = item;
+                builder.Append(item.Commit.SHA).Append(';');
             }
-        }
-
-        private void OnRowHeaderPointerPressed(object sender, PointerPressedEventArgs e)
-        {
-            if (sender is Border { DataContext: ViewModels.InteractiveRebaseItem item })
+            else
             {
-                var data = new DataObject();
-                data.Set("InteractiveRebaseItem", item);
-                DragDrop.DoDragDrop(e, data, DragDropEffects.Move | DragDropEffects.Copy | DragDropEffects.Link);
-            }
-        }
-
-        private void OnRowHeaderDragOver(object sender, DragEventArgs e)
-        {
-            if (DataContext is ViewModels.InteractiveRebase vm &&
-                e.Data.Contains("InteractiveRebaseItem") &&
-                e.Data.Get("InteractiveRebaseItem") is ViewModels.InteractiveRebaseItem src &&
-                sender is Border { DataContext: ViewModels.InteractiveRebaseItem dst } border &&
-                src != dst)
-            {
-                e.DragEffects = DragDropEffects.Move | DragDropEffects.Copy | DragDropEffects.Link;
-
-                var p = e.GetPosition(border);
-                if (p.Y > border.Bounds.Height * 0.33 && p.Y < border.Bounds.Height * 0.67)
+                foreach (var one in selected)
                 {
-                    var srcIdx = vm.Items.IndexOf(src);
-                    var dstIdx = vm.Items.IndexOf(dst);
-                    if (srcIdx < dstIdx)
-                    {
-                        for (var i = srcIdx; i < dstIdx; i++)
-                            vm.MoveItemDown(src);
-                    }
-                    else
-                    {
-                        for (var i = srcIdx; i > dstIdx; i--)
-                            vm.MoveItemUp(src);
-                    }
+                    if (one is ViewModels.InteractiveRebaseItem rebaseItem)
+                        builder.Append(rebaseItem.Commit.SHA).Append(';');
                 }
-
-                e.Handled = true;
             }
+
+            var data = new DataTransfer();
+            data.Add(DataTransferItem.Create(_dndItemFormat, builder.ToString()));
+            await DragDrop.DoDragDropAsync(e, data, DragDropEffects.Move);
         }
 
-        private void OnButtonActionClicked(object sender, RoutedEventArgs e)
+        private void OnRowDragOver(object sender, DragEventArgs e)
+        {
+            if (DataContext is not ViewModels.InteractiveRebase vm)
+                return;
+
+            if (e.DataTransfer.TryGetValue(_dndItemFormat) is not { Length: > 0 } hashes)
+                return;
+
+            if (sender is not Control { DataContext: ViewModels.InteractiveRebaseItem dst } control)
+                return;
+
+            if (hashes.IndexOf(dst.Commit.SHA, StringComparison.Ordinal) >= 0)
+                return;
+
+            var p = e.GetPosition(control);
+            var before = p.Y < control.Bounds.Height * 0.5;
+            dst.DropDirectionIndicator = before ? new Thickness(0, 2, 0, 0) : new Thickness(0, 0, 0, 2);
+            e.DragEffects = DragDropEffects.Move;
+            e.Handled = true;
+        }
+
+        private void OnRowDragLeave(object sender, DragEventArgs e)
+        {
+            if (sender is not Control { DataContext: ViewModels.InteractiveRebaseItem dst })
+                return;
+
+            dst.DropDirectionIndicator = new Thickness(0);
+            e.Handled = true;
+        }
+
+        private void OnRowDrop(object sender, DragEventArgs e)
+        {
+            if (DataContext is not ViewModels.InteractiveRebase vm)
+                return;
+
+            if (e.DataTransfer.TryGetValue(_dndItemFormat) is not { Length: > 0 } hashes)
+                return;
+
+            if (sender is not Control { DataContext: ViewModels.InteractiveRebaseItem dst } control)
+                return;
+
+            if (hashes.IndexOf(dst.Commit.SHA, StringComparison.Ordinal) >= 0)
+                return;
+
+            var selected = IRItemListBox.SelectedItems ?? new List<object>();
+            if (selected.Count == 0)
+                return;
+
+            var p = e.GetPosition(control);
+            var before = p.Y < control.Bounds.Height * 0.5;
+            var idx = vm.Items.IndexOf(dst);
+
+            var commits = new List<ViewModels.InteractiveRebaseItem>();
+            foreach (var item in selected)
+            {
+                if (item is ViewModels.InteractiveRebaseItem irItem)
+                    commits.Add(irItem);
+            }
+
+            vm.Move(commits, before ? idx : idx + 1);
+            IRItemListBox.SelectedItems = commits;
+
+            dst.DropDirectionIndicator = new Thickness(0);
+            e.DragEffects = DragDropEffects.None;
+            e.Handled = true;
+        }
+
+        private void OnMoveSelectedUp(object sender, RoutedEventArgs e)
+        {
+            if (DataContext is not ViewModels.InteractiveRebase vm)
+                return;
+
+            if (IRItemListBox.SelectedItems is not { Count: > 0 } selected)
+                return;
+
+            var hashes = new HashSet<string>();
+            var items = new List<ViewModels.InteractiveRebaseItem>();
+            foreach (var item in selected)
+            {
+                if (item is ViewModels.InteractiveRebaseItem irItem)
+                {
+                    hashes.Add(irItem.Commit.SHA);
+                    items.Add(irItem);
+                }
+            }
+
+            var idx = 0;
+            for (int i = 0; i < vm.Items.Count; i++)
+            {
+                if (hashes.Contains(vm.Items[i].Commit.SHA))
+                {
+                    idx = Math.Max(0, i - 1);
+                    break;
+                }
+            }
+
+            vm.Move(items, idx);
+            IRItemListBox.SelectedItems = items;
+            e.Handled = true;
+        }
+
+        private void OnMoveSelectedDown(object sender, RoutedEventArgs e)
+        {
+            if (DataContext is not ViewModels.InteractiveRebase vm)
+                return;
+
+            if (IRItemListBox.SelectedItems is not { Count: > 0 } selected)
+                return;
+
+            var hashes = new HashSet<string>();
+            var items = new List<ViewModels.InteractiveRebaseItem>();
+            foreach (var item in selected)
+            {
+                if (item is ViewModels.InteractiveRebaseItem irItem)
+                {
+                    hashes.Add(irItem.Commit.SHA);
+                    items.Add(irItem);
+                }
+            }
+
+            var idx = 0;
+            for (int i = vm.Items.Count - 1; i >= 0; i--)
+            {
+                if (hashes.Contains(vm.Items[i].Commit.SHA))
+                {
+                    idx = Math.Min(vm.Items.Count, i + 2);
+                    break;
+                }
+            }
+
+            vm.Move(items, idx);
+            IRItemListBox.SelectedItems = items;
+            e.Handled = true;
+        }
+
+        private void OnShowActionsDropdownMenu(object sender, RoutedEventArgs e)
         {
             if (sender is not Button { DataContext: ViewModels.InteractiveRebaseItem item } button)
                 return;
@@ -293,5 +492,6 @@ namespace SourceGit.Views
         }
 
         private bool _firstSelectionChangedHandled = false;
+        private readonly DataFormat<string> _dndItemFormat = DataFormat.CreateStringApplicationFormat("sourcegit-dnd-ir-item");
     }
 }
