@@ -38,7 +38,18 @@ namespace SourceGit.Views
             var selectedIdx = LauncherTabsList.SelectedIndex;
             var count = LauncherTabsList.ItemCount;
             var separatorPen = new Pen(this.FindResource("Brush.FG2") as IBrush, 0.5);
-            var separatorY = (height - 20) * 0.5;
+            var separatorY = (height - 18) * 0.5 + 1;
+
+            if (!IsScrollerVisible && selectedIdx > 0)
+            {
+                var container = LauncherTabsList.ContainerFromIndex(0);
+                if (container != null)
+                {
+                    var x = container.Bounds.Left - startX + LauncherTabsScroller.Bounds.X;
+                    context.DrawLine(separatorPen, new Point(x, separatorY), new Point(x, separatorY + 18));
+                }
+            }
+
             for (var i = 0; i < count; i++)
             {
                 if (i == selectedIdx || i == selectedIdx - 1)
@@ -56,7 +67,7 @@ namespace SourceGit.Views
                     break;
 
                 var separatorX = containerEndX - startX + LauncherTabsScroller.Bounds.X;
-                context.DrawLine(separatorPen, new Point(separatorX, separatorY), new Point(separatorX, separatorY + 20));
+                context.DrawLine(separatorPen, new Point(separatorX, separatorY), new Point(separatorX, separatorY + 18));
             }
 
             var selected = LauncherTabsList.ContainerFromIndex(selectedIdx);
@@ -161,16 +172,6 @@ namespace SourceGit.Views
             InvalidateVisual();
         }
 
-        private void SetupDragAndDrop(object sender, RoutedEventArgs e)
-        {
-            if (sender is Border border)
-            {
-                DragDrop.SetAllowDrop(border, true);
-                border.AddHandler(DragDrop.DropEvent, DropTab);
-            }
-            e.Handled = true;
-        }
-
         private void OnPointerPressedTab(object sender, PointerPressedEventArgs e)
         {
             if (sender is Border border)
@@ -196,7 +197,7 @@ namespace SourceGit.Views
             _startDragTab = false;
         }
 
-        private void OnPointerMovedOverTab(object sender, PointerEventArgs e)
+        private async void OnPointerMovedOverTab(object sender, PointerEventArgs e)
         {
             if (_pressedTab && !_startDragTab && sender is Border { DataContext: ViewModels.LauncherPage page } border)
             {
@@ -207,23 +208,42 @@ namespace SourceGit.Views
 
                 _startDragTab = true;
 
-                var data = new DataObject();
-                data.Set("MovedTab", page);
-                DragDrop.DoDragDrop(e, data, DragDropEffects.Move);
+                var data = new DataTransfer();
+                data.Add(DataTransferItem.Create(_dndMainTabFormat, page.Node.Id));
+                await DragDrop.DoDragDropAsync(e, data, DragDropEffects.Move);
             }
             e.Handled = true;
         }
 
         private void DropTab(object sender, DragEventArgs e)
         {
-            if (e.Data.Contains("MovedTab") &&
-                e.Data.Get("MovedTab") is ViewModels.LauncherPage moved &&
-                sender is Border { DataContext: ViewModels.LauncherPage to } &&
-                to != moved)
+            if (e.DataTransfer.TryGetValue(_dndMainTabFormat) is not { Length: > 0 } id)
+                return;
+
+            if (DataContext is not ViewModels.Launcher launcher)
+                return;
+
+            ViewModels.LauncherPage target = null;
+            foreach (var page in launcher.Pages)
             {
-                (DataContext as ViewModels.Launcher)?.MoveTab(moved, to);
+                if (page.Node.Id.Equals(id, StringComparison.Ordinal))
+                {
+                    target = page;
+                    break;
+                }
             }
 
+            if (target == null)
+                return;
+
+            if (sender is not Border { DataContext: ViewModels.LauncherPage to })
+                return;
+
+            if (target == to)
+                return;
+
+            launcher.MoveTab(target, to);
+
             _pressedTab = false;
             _startDragTab = false;
             e.Handled = true;
@@ -317,5 +337,6 @@ namespace SourceGit.Views
         private bool _pressedTab = false;
         private Point _pressedTabPosition = new();
         private bool _startDragTab = false;
+        private readonly DataFormat<string> _dndMainTabFormat = DataFormat.CreateStringApplicationFormat("sourcegit-dnd-main-tab");
     }
 }
